This is support for the function profile.nlreg.
It is not intended to be called directly by users.
# S3 method for nlreg
allProfiles(fitted, hoa = TRUE, precision = 6, signif = 30,
n = 50, omit = 0.5, trace = FALSE, call, …)a fitted nlreg object such as returned by a call to
nlreg.
logical value indicating whether higher order statistics should be
calculated; default is TRUE.
numerical value defining the maximum range of values, given by
MLE \(\pm\) precision*s.e., that
are profiled. The default is 6.
the maximum number of output points that are calculated exactly; default is 30.
the approximate number of output points produced by the spline interpolation; default is 50.
numerical value defining the range of values, given by
MLE \(\pm\) omit*s.e., which is
omitted in the spline interpolation of the higher order statistics
considered. The purpose is to avoid numerical instabilities
around the maximum likelihood estimate.
if TRUE, details of the iterations are printed.
absorbs any additional argument.
a list of elements of class all.nlreg.profiles for profiling
all parameters of a nonlinear heteroscedastic model.
The allProfiles.nlreg function is called internally by the
profile.nlreg routine. It is not intended to
be called directly by users.