Learn R Programming

nlreg (version 1.2-0)

print.summary.mpl: Use print() on a `summary.mpl' object

Description

This is a method for the function print() for objects inheriting from class summary.mpl. See print and print.default for the general behaviour of this function and for the interpretation of x and digits.

Usage

## S3 method for class 'summary.mpl':
print(x, corr = FALSE, digits = value, \dots)

Arguments

synopsis

## S3 method for class 'summary.mpl': print(x, corr = FALSE, digits = if(!is.null(x$digits)) x$digits else max(3, getOption("digits")-3), ...)

Details

The corr argument is a logical value indicating whether the (asymptotic) correlation matrix of the MLEs of the regression coefficients should be printed.

See Also

summary.mpl, print, print.default